@@ -1,3 +1,5 @@
+import logging
+
 from sigla import process_node
 from sigla.lib.SiglaFile import SiglaFile
 from sigla.lib.helpers.loaders import load_xml, load_string
@@ -14,11 +16,9 @@ def run(file=None, content=None):
     result = process_node(root)
     for r in result:
         if type(r) == SiglaFile:
-            print(f"|> Saving to {r.path}")
-            r.save("output")
+            logging.info(f"[Render] Saving generated file to {r.path}")
+            r.save()
         elif type(r) == str:
             print(r)
         else:
-            raise NotImplementedError(
-                f"No final handling implemented for {type(r)}"
-            )
\ No newline at end of file
+            raise NotImplementedError(f"No final handling implemented for {type(r)}")
\ No newline at end of file
